==> owncloud-10.2.0.zip: owncloud/settings/l10n/nn_NO.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Feil passord",
    "No user supplied" : "Ingen brukar gjeve",
    "Authentication error" : "Autentiseringsfeil",
    "Wrong admin recovery password. Please check the password and try again." : "Feil admingjenopprettingspassord. Ver venleg og sjekk passordet og prøv igjen.",
    "Unable to change password" : "Klarte ikkje å endra passordet",
    "Couldn't send reset email. Please contact your administrator." : "Kunne ikkje senda e-post for nullstilling, kontakt administratoren.",
    "Federated Cloud Sharing" : "Klarert sky deling",
    "Email sent" : "E-post sendt",
    "__language_name__" : "Nynorsk",
    "Language changed" : "Språk endra",
    "Invalid request" : "Ugyldig førespurnad",
    "Admins can't remove themself from the admin group" : "Administratorar kan ikkje fjerna seg sjølve frå admin-gruppa",
    "All" : "Alle",
    "Please wait...." : "Ver venleg og vent …",
    "Error while disabling app" : "Klarte ikkje å skru av programmet",
    "Disable" : "Slå av",
    "Enable" : "Slå på",
    "Error while enabling app" : "Klarte ikkje å skru på programmet",
    "Updating...." : "Oppdaterer …",
    "Error while updating app" : "Feil ved oppdatering av app",
    "Updated" : "Oppdatert",
    "Delete" : "Slett",
    "Select a profile picture" : "Vel eit profilbilete",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "So-so password" : "Middelmåtig passord",
    "Good password" : "OK passord",
    "Strong password" : "Sterkt passord",
    "Groups" : "Grupper",
    "undo" : "angra",
    "never" : "aldri",
    "add group" : "legg til gruppe",
    "A valid username must be provided" : "Du må oppgje eit gyldig brukarnamn",
    "A valid password must be provided" : "Du må oppgje eit gyldig passord",
    "Cheers!" : "Skål!",
    "Forum" : "Forum",
    "Cron" : "Cron",
    "Open documentation" : "Opne dokumentasjon.",
    "Execute one task with each page loaded" : "Utfør éi oppgåve for kvar sidelasting",
    "Sharing" : "Deling",
    "Allow apps to use the Share API" : "La app-ar bruka API-et til deling",
    "Allow public uploads" : "Tillat offentlege opplastingar",
    "days" : "dagar",
    "Allow resharing" : "Tillat vidaredeling",
    "Log" : "Logg",
    "None" : "Ingen",
    "Login" : "Logg inn",
    "Encryption" : "Kryptering",
    "Server address" : "Tenaradresse",
    "Port" : "Port",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-modulen «fileinfo» manglar. Me rår sterkt til å slå på denne modulen for å best mogleg oppdaga MIME-typar.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Spesielt ved bruk av klient for å synkronisera bør ein ikkje bruka SQLite.",
    "Get the apps to sync your files" : "Få app-ar som kan synkronisera filene dine",
    "Show First Run Wizard again" : "Vis Oppstartvegvisaren igjen",
    "Profile picture" : "Profilbilete",
    "Upload new" : "Last opp ny",
    "Remove image" : "Fjern bilete",
    "Cancel" : "Avbryt",
    "Email" : "E-post",
    "Your email address" : "Di epost-adresse",
    "Password" : "Passord",
    "Unable to change your password" : "Klarte ikkje endra passordet",
    "Current password" : "Passord",
    "New password" : "Nytt passord",
    "Change password" : "Endra passord",
    "Language" : "Språk",
    "Help translate" : "Hjelp oss å omsetja",
    "Unlimited" : "Ubegrensa",
    "Name" : "Namn",
    "Username" : "Brukarnamn",
    "Version" : "Utgåve",
    "Personal" : "Personleg",
    "Admin" : "Admin",
    "Error" : "Feil",
    "E-Mail" : "E-post",
    "Create" : "Lag",
    "Admin Recovery Password" : "Gjenopprettingspassord for administrator",
    "Enter the recovery password in order to recover the users files during password change" : "Skriv inn gjenopprettingspassordet brukt for å gjenoppretta brukarfilene ved passordendring",
    "Group" : "Gruppe",
    "Other" : "Anna",
    "Quota" : "Kvote",
    "set new password" : "lag nytt passord",
    "Default" : "Standard",
    "Saved" : "Lagra",
    "Share" : "Del",
    "What to log" : "Kva skal sparast",
    "Add" : "Legg til",
    "%s password changed successfully" : "%spassord er endra",
    "Download logfile (%s)" : "Last ned logg (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Logg fil er større enn 100MB. Nedlasting kan ta tid.",
    "Desktop client" : "Skrivebord klient",
    "Android app" : "Android program",
    "iOS app" : "iOS program"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/settings/l10n/nn_NO.js <==
OC.L10N.register(
    "settings",
    {
    "No user supplied" : "Ingen brukar gjeve",
    "Authentication error" : "Autentiseringsfeil",
    "Wrong admin recovery password. Please check the password and try again." : "Feil admingjenopprettingspassord. Ver venleg og sjekk passordet og prøv igjen.",
    "Unable to change password" : "Klarte ikkje å endra passordet",
    "%s password changed successfully" : "%spassord er endra",
    "Couldn't send reset email. Please contact your administrator." : "Kunne ikkje senda e-post for nullstilling, kontakt administratoren.",
    "Saved" : "Lagra",
    "Email sent" : "E-post sendt",
    "Create" : "Lag",
    "Delete" : "Slett",
    "Share" : "Del",
    "Language changed" : "Språk endra",
    "Invalid request" : "Ugyldig førespurnad",
    "Admins can't remove themself from the admin group" : "Administratorar kan ikkje fjerna seg sjølve frå admin-gruppa",
    "All" : "Alle",
    "Please wait...." : "Ver venleg og vent …",
    "Error while disabling app" : "Klarte ikkje å skru av programmet",
    "Disable" : "Slå av",
    "Enable" : "Slå på",
    "Error while enabling app" : "Klarte ikkje å skru på programmet",
    "Updating...." : "Oppdaterer …",
    "Error while updating app" : "Feil ved oppdatering av app",
    "Updated" : "Oppdatert",
    "Select a profile picture" : "Vel eit profilbilete",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "So-so password" : "Middelmåtig passord",
    "Good password" : "OK passord",
    "Strong password" : "Sterkt passord",
    "Groups" : "Grupper",
    "undo" : "angra",
    "Delete group" : "Slett gruppe",
    "never" : "aldri",
    "add group" : "legg til gruppe",
    "A valid username must be provided" : "Du må oppgje eit gyldig brukarnamn",
    "A valid password must be provided" : "Du må oppgje eit gyldig passord",
    "Cheers!" : "Skål!",
    "Forum" : "Forum",
    "Language" : "Språk",
    "Cron" : "Cron",
    "Open documentation" : "Opne dokumentasjon.",
    "Execute one task with each page loaded" : "Utfør éi oppgåve for kvar sidelasting",
    "Sharing" : "Deling",
    "Allow apps to use the Share API" : "La app-ar bruka API-et til deling",
    "Allow public uploads" : "Tillat offentlege opplastingar",
    "days" : "dagar",
    "Allow resharing" : "Tillat vidaredeling",
    "None" : "Ingen",
    "Log" : "Logg",
    "What to log" : "Kva skal sparast",
    "Download logfile (%s)" : "Last ned logg (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Logg fil er større enn 100MB. Nedlasting kan ta tid.",
    "Login" : "Logg inn",
    "Encryption" : "Kryptering",
    "Server address" : "Tenaradresse",
    "Port" : "Port",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-modulen «fileinfo» manglar. Me rår sterkt til å slå på denne modulen for å best mogleg oppdaga MIME-typar.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Spesielt ved bruk av klient for å synkronisera bør ein ikkje bruka SQLite.",
    "Get the apps to sync your files" : "Få app-ar som kan synkronisera filene dine",
    "Desktop client" : "Skrivebord klient",
    "Android app" : "Android program",
    "iOS app" : "iOS program",
    "Show First Run Wizard again" : "Vis Oppstartvegvisaren igjen",
    "Add" : "Legg til",
    "Profile picture" : "Profilbilete",
    "Upload new" : "Last opp ny",
    "Remove image" : "Fjern bilete",
    "Cancel" : "Avbryt",
    "Email" : "E-post",
    "Your email address" : "Di epost-adresse",
    "Password" : "Passord",
    "Unable to change your password" : "Klarte ikkje endra passordet",
    "Current password" : "Passord",
    "New password" : "Nytt passord",
    "Change password" : "Endra passord",
    "Help translate" : "Hjelp oss å omsetja",
    "Name" : "Namn",
    "Username" : "Brukarnamn",
    "Version" : "Utgåve",
    "New Password" : "Nytt passord",
    "Personal" : "Personleg",
    "Admin" : "Admin",
    "Other" : "Anna",
    "Settings" : "Innstillingar",
    "E-Mail" : "E-brev",
    "Admin Recovery Password" : "Gjenopprettingspassord for administrator",
    "Enter the recovery password in order to recover the users files during password change" : "Skriv inn gjenopprettingspassordet brukt for å gjenoppretta brukarfilene ved passordendring",
    "Group" : "Gruppe",
    "Unlimited" : "Ubegrensa",
    "Quota" : "Kvote",
    "set new password" : "lag nytt passord",
    "Default" : "Standard"
},
"nplurals=2; plural=(n != 1);");
